context("canvasXpress Web Charts - Histogram")


test_that("cXhistogram1", {
    check_ui_test(cXhistogram1())
})

test_that("cXhistogram2", {
    check_ui_test(cXhistogram2())
})

test_that("cXhistogram3", {
    check_ui_test(cXhistogram3())
})

test_that("cXhistogram4", {
    check_ui_test(cXhistogram4())
})

test_that("cXhistogram5", {
    check_ui_test(cXhistogram5())
})

test_that("cXhistogram6", {
    check_ui_test(cXhistogram6())
})

test_that("cXhistogram7", {
    check_ui_test(cXhistogram7())
})
